use openssl::ssl::SslContext;

#[derive(Clone)]
pub struct SslCert {
    context: SslContext,
}

fn generate_ctx(cert_file: &str, key_file: &str) -> Option<SslContext> {
    use openssl::ssl::{SslFiletype, SslMethod};

    let mut ctx = SslContext::builder(SslMethod::tls()).ok().unwrap();
    ctx.set_private_key_file(&key_file, SslFiletype::PEM).ok().unwrap();
    ctx.set_certificate_file(&cert_file, SslFiletype::PEM).ok().unwrap();
    ctx.check_private_key().ok()?;
    Some(ctx.build())
}

impl SslCert {
    pub fn new(cert_file: &str, key_file: &str) -> Option<SslCert> {
        Some(SslCert {
            context: generate_ctx(cert_file, key_file)?
        })
    }

    pub fn get_context(&self) -> SslContext {
        self.context.clone()
    }
}